/****************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Outrun demo.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

import QtQuick
import QtQuick.Window
import RemoteControl

Window {
    id: mainWindow
    width: 1920
    height: 720
    visible: true
    title: qsTr("Outrun Cluster")

    Outrun_Cluster {
        id: outrunMain
        anchors.fill: parent
//        fakeReflections: android

        Component.onCompleted: {
            remoteControl.startServer();
            fadeOutTimer.interval = 30000;
            fadeOutTimer.start();
        }
    }

    Rectangle {
        id: remoteDisplay
        color: "#09102b"
        radius: 10
        width: remoteText.width + 100
        height: 100
        anchors.top: parent.top
        anchors.topMargin: 50
        anchors.horizontalCenter: parent.horizontalCenter

        Behavior on opacity {
            NumberAnimation { duration: 500 }
        }

        Text {
            id: remoteText
            anchors.centerIn: parent
            font.pixelSize: 50
            text: "Connect to " + remoteControl.ipAddress;
            color: "#f3f3f4"
        }
    }

    Receiver {
        id: remoteControl

        onRemoteConnected: {
            remoteText.text = "Remote Control Connected";
            fadeOutTimer.interval = 2000;
            fadeOutTimer.start();
        }

        onRemoteDisconnected: {
            remoteDisplay.opacity = 1.0;
            remoteText.text = "Connect to " + ipAddress;
            fadeOutTimer.interval = 60000;
            fadeOutTimer.start();
        }

        onCommandsReceived: {
            outrunMain.executeCommand(commands);
        }
    }

    Timer {
        id: fadeOutTimer
        running: false
        interval: 2000
        onTriggered: {
            remoteDisplay.opacity = 0.0;
        }
    }
}
